@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Plus42 -- an enhanced HP-42S calculator simulator
- * Copyright (C) 2004-2025  Thomas Okken
+ * Copyright (C) 2004-2026  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -697,7 +697,7 @@ void clear_rtns_vars_and_prgms();
 int clear_prgm(const arg_struct *arg);
 int clear_prgm_by_int_index(int prgm);
 void clear_prgm_lines(int4 count);
-void goto_dot_dot(bool force_new);
+bool goto_dot_dot(bool force_new);
 bool mvar_prgms_exist();
 bool label_has_mvar(int4 dir_id, int lblindex);
 int get_command_length(pgm_index prgm, int4 pc);
@@ -707,7 +707,7 @@ void count_embed_references(directory *dir, int prgm, bool up);
 void delete_command(int4 pc);
 int eqn_flip(int4 pc);
 bool store_command(int4 pc, int command, arg_struct *arg, const char *num_str);
-void store_command_after(int4 *pc, int command, arg_struct *arg, const char *num_str);
+bool store_command_after(int4 *pc, int command, arg_struct *arg, const char *num_str);
 int x2line();
 int a2line(bool append);
 int prgm_lock(bool lock);
